@@ -29,7 +29,6 @@ from pytorch_lightning.core.memory import ModelSummary
 from pytorch_lightning.core.saving import ALLOWED_CONFIG_TYPES, PRIMITIVE_TYPES, ModelIO
 from pytorch_lightning.utilities import rank_zero_warn
 from pytorch_lightning.utilities.device_dtype_mixin import DeviceDtypeModuleMixin
-from pytorch_lightning.core.step_result import TrainResult, EvalResult
 from pytorch_lightning.utilities.xla_device_utils import XLADeviceUtils
 from pytorch_lightning.utilities.exceptions import MisconfigurationException
 from pytorch_lightning.core.step_result import Result
@@ -108,9 +107,20 @@ class LightningModule(
         # optionally can be set by user
         self._example_input_array = None
         self._datamodule = None
-        self._results: Result = None
+        self._results: Optional[Result] = None
         self._current_fx_name = ''
 
+    def optimizers(self):
+        opts = self.trainer.optimizers
+
+        # single optimizer
+        if isinstance(opts, list) and len(opts) == 1 and isinstance(opts[0], Optimizer):
+            return opts[0]
+
+        # multiple opts
+        else:
+            return opts
+
     @property
     def example_input_array(self) -> Any:
         return self._example_input_array
@@ -400,7 +410,11 @@ class LightningModule(
                 :paramref:`~pytorch_lightning.trainer.trainer.Trainer.truncated_bptt_steps` > 0.
 
         Return:
-            roch.Tensor or a dictionary with anything you want (must include the keyword 'loss')
+            Any of.
+
+            - :class:`~torch.Tensor` - The loss tensor
+            - `dict` - A dictionary. Can include any keys, but must include the key 'loss'
+            - `None` - Training will skip to the next batch
 
         In this step you'd normally do the forward pass and calculate the loss for a batch.
         You can also do fancier things like multiple forward passes or something model specific.
@@ -439,7 +453,7 @@ class LightningModule(
                 ...
                 return {'loss': loss, 'hiddens': hiddens}
 
-        Notes:
+        Note:
             The loss value shown in the progress bar is smoothed (averaged) over the last values,
             so it differs from the actual loss returned in train/validation step.
         """
@@ -572,7 +586,10 @@ class LightningModule(
                 (only if multiple val datasets used)
 
         Return:
-            None or whatever you want
+           Any of.
+
+            - Any object or value
+            - `None` - Validation will skip to the next batch
 
         .. code-block:: python
 
@@ -686,13 +703,6 @@ class LightningModule(
             See the :ref:`multi_gpu` guide for more details.
         """
 
-    def validation_end(self, outputs):
-        """
-        Warnings:
-            Deprecated in v0.7.0. Use :meth:`validation_epoch_end` instead.
-            Will be removed in 1.0.0.
-        """
-
     def validation_epoch_end(
         self, outputs: List[Any]
     ) -> None:
@@ -763,7 +773,10 @@ class LightningModule(
                 (only if multiple test datasets used).
 
         Return:
-            None or anything
+           Any of.
+
+            - Any object or value
+            - `None` - Testing will skip to the next batch
 
         .. code-block:: python
 
@@ -848,7 +861,7 @@ class LightningModule(
 
                 out = self(x)
                 loss = self.softmax(out)
-                result.log('test_loss', loss)
+                self.log('test_loss', loss)
 
             # --------------
             # with test_step_end to do softmax over the full batch
@@ -869,13 +882,6 @@ class LightningModule(
             See the :ref:`multi_gpu` guide for more details.
         """
 
-    def test_end(self, outputs):
-        """
-        Warnings:
-             Deprecated in v0.7.0. Use :meth:`test_epoch_end` instead.
-             Will be removed in 1.0.0.
-        """
-
     def test_epoch_end(
         self, outputs: List[Any]
     ) -> None:
@@ -1049,6 +1055,73 @@ class LightningModule(
             "`configure_optimizers` must be implemented to be used with the Lightning Trainer"
         )
 
+    def manual_backward(self, loss: Tensor, optimizer: Optimizer, *args, **kwargs) -> None:
+        """
+        Call this directly from your training_step when doing optimizations manually.
+        By using this we can ensure that all the proper scaling when using 16-bit etc has been done for you
+
+        This function forwards all args to the .backward() call as well.
+
+        .. tip:: In manual mode we still automatically clip grads if Trainer(gradient_clip_val=x) is set
+
+        Example::
+
+            def training_step(...):
+                (opt_a, opt_b) = self.optimizers()
+                loss = ...
+                # automatically applies scaling, etc...
+                self.manual_backward(loss, opt_a)
+        """
+        # make sure we're using manual opt
+        self._verify_is_manual_optimization('manual_backward')
+
+        # backward
+        self.trainer.train_loop.backward(loss, optimizer, -1, *args, **kwargs)
+
+        # clip grads after backward
+        self.trainer.accelerator_backend.clip_gradients(optimizer)
+
+    def backward(self, loss: Tensor, optimizer: Optimizer, optimizer_idx: int) -> None:
+        """
+        Override backward with your own implementation if you need to.
+
+        Args:
+            loss: Loss is already scaled by accumulated grads
+            optimizer: Current optimizer being used
+            optimizer_idx: Index of the current optimizer being used
+
+        Called to perform backward step.
+        Feel free to override as needed.
+        The loss passed in has already been scaled for accumulated gradients if requested.
+
+        Example::
+
+            def backward(self, loss, optimizer, optimizer_idx):
+                loss.backward()
+
+        """
+        loss.backward()
+
+    def toggle_optimizer(self, optimizer: Optimizer, optimizer_idx: int):
+        """
+        Makes sure only the gradients of the current optimizer's parameters are calculated
+        in the training step to prevent dangling gradients in multiple-optimizer setup.
+
+        .. note:: Only called when using multiple optimizers
+
+        Override for your own behavior
+
+        Args:
+            optimizer:
+            optimizer_idx:
+        """
+        for param in self.parameters():
+            param.requires_grad = False
+
+        for group in optimizer.param_groups:
+            for param in group['params']:
+                param.requires_grad = True
+
     def optimizer_step(
         self,
         epoch: int,
@@ -1289,23 +1362,10 @@ class LightningModule(
 
         return tqdm_dict
 
-    def get_tqdm_dict(self) -> Dict[str, Union[int, str]]:
-        """
-        Additional items to be displayed in the progress bar.
-
-        Return:
-            Dictionary with the items to be displayed in the progress bar.
-
-        Warning:
-            Deprecated since v0.7.3.
-            Use :meth:`get_progress_bar_dict` instead.
-        """
-        rank_zero_warn(
-            "`get_tqdm_dict` was renamed to `get_progress_bar_dict` in v0.7.3"
-            " and this method will be removed in v1.0.0",
-            DeprecationWarning,
-        )
-        return self.get_progress_bar_dict()
+    def _verify_is_manual_optimization(self, fn_name):
+        if self.trainer.train_loop.automatic_optimization:
+            m = f'to use {fn_name}, please disable automatic optimization: Trainer(automatic_optimization=False)'
+            raise MisconfigurationException(m)
 
     @classmethod
     def _auto_collect_arguments(cls, frame=None) -> Tuple[Dict, Dict]:
