@@ -23,6 +23,20 @@ class NativeAMP:
     def connect(self, model, optimizers):
         return model, optimizers
 
+    def backward(self, closure_loss, optimizer, opt_idx, *args, **kwargs):
+        closure_loss = self.trainer.scaler.scale(closure_loss)
+
+        # do backward pass
+        if self.trainer.train_loop.automatic_optimization:
+            model = self.trainer.get_model()
+            model.backward(closure_loss, optimizer, opt_idx)
+        else:
+            closure_loss.backward(*args, **kwargs)
+
+        # once backward has been applied, release graph
+        closure_loss = closure_loss.detach()
+        return closure_loss
+
     def training_step(self, fx, args):
         with torch.cuda.amp.autocast():
             output = fx(*args)
