@@ -28,8 +28,8 @@ from pytorch_lightning.loggers import LightningLoggerBase
 from pytorch_lightning.profiler import BaseProfiler
 from pytorch_lightning.trainer.callback_hook import TrainerCallbackHookMixin
 from pytorch_lightning.trainer.configuration_validator import ConfigValidator
+from pytorch_lightning.trainer.connectors.env_vars_connector import overwrite_by_env_vars
 from pytorch_lightning.trainer.data_loading import TrainerDataLoadingMixin
-from pytorch_lightning.trainer.deprecated_api import TrainerDeprecatedAPITillVer0_11
 from pytorch_lightning.trainer.logging import TrainerLoggingMixin
 from pytorch_lightning.trainer.model_hooks import TrainerModelHooksMixin
 from pytorch_lightning.trainer.optimizers import TrainerOptimizersMixin
@@ -57,7 +57,9 @@ from pytorch_lightning.trainer.connectors.data_connector import DataConnector
 from pytorch_lightning.utilities.cloud_io import load as pl_load
 from pytorch_lightning.utilities.model_utils import is_overridden
 from pytorch_lightning.trainer.properties import TrainerProperties
-from pytorch_lightning.cluster_environments.cluster_environment import ClusterEnvironment
+from pytorch_lightning.plugins.plugin_connector import PluginConnector
+from pytorch_lightning.accelerators.accelerator import Accelerator
+from pytorch_lightning.accelerators.cpu_accelerator import CPUAccelerator
 
 # warnings to ignore in trainer
 warnings.filterwarnings(
@@ -79,13 +81,12 @@ class Trainer(
     TrainerLoggingMixin,
     TrainerTrainingTricksMixin,
     TrainerDataLoadingMixin,
-    TrainerDeprecatedAPITillVer0_11,
 ):
+    @overwrite_by_env_vars
     def __init__(
         self,
         logger: Union[LightningLoggerBase, Iterable[LightningLoggerBase], bool] = True,
         checkpoint_callback: Union[ModelCheckpoint, bool] = True,
-        early_stop_callback: Optional[Union[EarlyStopping, bool]] = False,  # todo: remove in v1.0.0
         callbacks: Optional[List[Callback]] = None,
         default_root_dir: Optional[str] = None,
         gradient_clip_val: float = 0,
@@ -112,10 +113,10 @@ class Trainer(
         val_check_interval: Union[int, float] = 1.0,
         flush_logs_every_n_steps: int = 100,
         log_every_n_steps: int = 50,
-        distributed_backend: Optional[str] = None,
+        accelerator: Optional[Union[str, Accelerator]] = None,
         sync_batchnorm: bool = False,
         precision: int = 32,
-        weights_summary: Optional[str] = ModelSummary.MODE_DEFAULT,
+        weights_summary: Optional[str] = 'top',
         weights_save_path: Optional[str] = None,
         num_sanity_val_steps: int = 2,
         truncated_bptt_steps: Optional[int] = None,
@@ -129,18 +130,20 @@ class Trainer(
         terminate_on_nan: bool = False,
         auto_scale_batch_size: Union[str, bool] = False,
         prepare_data_per_node: bool = True,
-        cluster_environment: ClusterEnvironment = None,
+        plugins: list = None,
         amp_backend: str = 'native',
         amp_level: str = 'O2',
-        overfit_pct: float = None,  # backward compatible, todo: remove in v1.0.0
-        log_save_interval: Optional[int] = None,  # backward compatible, todo: remove in 0.11
-        row_log_interval: Optional[int] = None,  # backward compatible, todo: remove in 0.11
+        distributed_backend: Optional[str] = None,
+        automatic_optimization: bool = True,
     ):
         r"""
         Customize every aspect of training via flags
 
         Args:
 
+            accelerator: Previously known as distributed_backend (dp, ddp, ddp2, etc...).
+                Can also take in an accelerator object for custom hardware.
+
             accumulate_grad_batches: Accumulates grads every k batches or as set up in the dict.
 
             amp_backend: The mixed precision backend to use ("native" or "apex")
@@ -171,20 +174,13 @@ class Trainer(
 
             check_val_every_n_epoch: Check val every n train epochs.
 
-            cluster_environment: Environment config to link up arbitrary clusters
-
             default_root_dir: Default path for logs and weights when no logger/ckpt_callback passed.
                 Default: ``os.getcwd()``.
                 Can be remote file paths such as `s3://mybucket/path` or 'hdfs://path/'
 
             deterministic: If true enables cudnn.deterministic.
 
-            distributed_backend: The distributed backend to use (dp, ddp, ddp2, ddp_spawn, ddp_cpu)
-
-            early_stop_callback (:class:`pytorch_lightning.callbacks.EarlyStopping`).
-                .. warning:: .. deprecated:: 0.10.0
-
-                    Will be removed in v1.0.
+            distributed_backend: deprecated. Please use 'accelerator'
 
             fast_dev_run: runs 1 batch of train, test and val to find any bugs (ie: a sort of unit test).
 
@@ -206,10 +202,8 @@ class Trainer(
 
             log_every_n_steps: How often to log within steps (defaults to every 50 steps).
 
-            log_save_interval: How often to flush logs to disk.
-                .. warning:: .. deprecated:: 0.10.0
-
-                    Use `flush_logs_every_n_steps` instead. Will remove v0.11.0.
+            automatic_optimization: If False you are responsible for calling .backward, .step, zero_grad.
+                Meant to be used with multiple optimizers by advanced users.
 
             prepare_data_per_node: If True, each LOCAL_RANK=0 will call prepare data.
                 Otherwise only NODE_RANK=0, LOCAL_RANK=0 will prepare data
@@ -223,6 +217,8 @@ class Trainer(
 
             overfit_batches: Overfit a percent of training data (float) or a set number of batches (int). Default: 0.0
 
+            plugins: Plugins allow modification of core behavior like ddp and amp.
+
             precision: Full precision (32), half precision (16). Can be used on CPU, GPU or TPUs.
 
             max_epochs: Stop training once this number of epochs is reached.
@@ -248,11 +244,6 @@ class Trainer(
             resume_from_checkpoint: To resume training from a specific checkpoint pass in the path here.
                 This can be a URL.
 
-            row_log_interval: How often to log within steps.
-                .. warning:: .. deprecated:: 0.10.0
-
-                    Use `log_every_n_steps` instead. Will remove v0.11.0.
-
             sync_batchnorm: Synchronize batch norm layers between process groups/whole world.
 
             terminate_on_nan: If set to True, will terminate training (by raising a `ValueError`) at the
@@ -278,19 +269,6 @@ class Trainer(
         """
         super().__init__()
 
-        # deprecation warnings
-        if row_log_interval is not None:
-            warnings.warn("Argument `row_log_interval` is deprecated in v0.10, use `log_every_n_steps` instead."
-                          " It will be removed in v0.11.0.", DeprecationWarning)
-            log_every_n_steps = row_log_interval
-
-        if log_save_interval is not None:
-            warnings.warn(
-                "Argument `log_save_interval` is deprecated in v0.10, use `flush_logs_every_n_steps` instead."
-                " It will be removed in v0.11.0.", DeprecationWarning
-            )
-            flush_logs_every_n_steps = log_save_interval
-
         # init connectors
         self.dev_debugger = InternalDebugger(self)
         self.config_validator = ConfigValidator(self)
@@ -310,6 +288,7 @@ class Trainer(
         self.accelerator_backend = None
         self.evaluation_loop = EvaluationLoop(self)
         self.train_loop = TrainLoop(self)
+        self.plugin_connector = PluginConnector(self)
 
         # training state
         self.weights_summary = weights_summary
@@ -319,10 +298,8 @@ class Trainer(
         # init callbacks
         # Declare attributes to be set in callback_connector on_trainer_init
         self.checkpoint_callback: Union[ModelCheckpoint, bool] = checkpoint_callback
-        self.early_stop_callback: Optional[Union[EarlyStopping, bool]] = early_stop_callback
         self.callback_connector.on_trainer_init(
             callbacks,
-            early_stop_callback,
             checkpoint_callback,
             progress_bar_refresh_rate,
             process_position,
@@ -351,6 +328,7 @@ class Trainer(
         self.accelerator_connector.on_trainer_init(
             num_processes,
             tpu_cores,
+            accelerator,
             distributed_backend,
             auto_select_gpus,
             gpus,
@@ -360,11 +338,17 @@ class Trainer(
             benchmark,
             replace_sampler_ddp,
             deterministic,
-            cluster_environment
         )
 
         # init train loop related flags
-        self.train_loop.on_trainer_init(max_epochs, min_epochs, max_steps, min_steps, num_sanity_val_steps)
+        self.train_loop.on_trainer_init(
+            max_epochs,
+            min_epochs,
+            max_steps,
+            min_steps,
+            num_sanity_val_steps,
+            automatic_optimization
+        )
         self.evaluation_loop.on_trainer_init()
 
         # configure tuner
@@ -378,7 +362,6 @@ class Trainer(
 
         # init debugging flags
         self.debugging_connector.on_init_start(
-            overfit_pct,
             limit_train_batches,
             limit_val_batches,
             limit_test_batches,
@@ -390,6 +373,9 @@ class Trainer(
         # set precision
         self.precision_connector.on_trainer_init(precision, amp_level, amp_backend)
 
+        # last thing are the plugins which override whatever the trainer used by default
+        self.plugin_connector.on_trainer_init(plugins)
+
         # Callback system
         self.on_init_end()
 
@@ -490,10 +476,6 @@ class Trainer(
             # run all epochs
             for epoch in range(self.current_epoch, self.max_epochs):
 
-                # reset train dataloader
-                if self.reload_dataloaders_every_epoch:
-                    self.reset_train_dataloader(model)
-
                 # hook
                 self.train_loop.on_train_epoch_start(epoch)
 
@@ -587,7 +569,7 @@ class Trainer(
                 output = self.evaluation_loop.evaluation_step_end(output)
 
                 # hook
-                self.evaluation_loop.on_evaluation_batch_end(batch, batch_idx, dataloader_idx)
+                self.evaluation_loop.on_evaluation_batch_end(output, batch, batch_idx, dataloader_idx)
 
                 # clean up
                 self.evaluation_loop.evaluation_batch_end_cleanup(output, batch_idx, dataloader_idx)
